@@ -1,4 +1,4 @@
-// Copyright (C) 2016  Stefan Vargyas
+// Copyright (C) 2016, 2017  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -124,6 +124,12 @@
 #define VERIFY_SIZE_NOT_NULL(x) \
     SIZE_NOT_NULL_(VERIFY, x)
 
+#define UINT_TO_SIZE(x)                                       \
+    ({                                                        \
+        STATIC(TYPE_UNSIGNED_INT_MAX(TYPEOF(x)) <= SIZE_MAX); \
+        (size_t) (x);                                         \
+    })
+
 #define INT_AS_SIZE(x)                                      \
     ({                                                      \
         STATIC(TYPE_SIGNED_INT_MAX(TYPEOF(x)) <= SIZE_MAX); \
