@@ -1,4 +1,4 @@
-// Copyright (C) 2016  Stefan Vargyas
+// Copyright (C) 2016, 2017  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -27,6 +27,10 @@ extern const char help[];
 
 extern const char stdin_name[];
 
+void error(const char* fmt, ...)
+    PRINTF(1)
+    NORETURN;
+
 #define KB(X) (SZ(X) * SZ(1024))
 #define MB(X) (KB(X) * SZ(1024))
 
@@ -38,6 +42,9 @@ struct su_size_t
 
 struct su_size_t su_size(size_t sz);
 
+size_t parse_num(
+    const char* p, const char** q, int b);
+
 typedef bool (*options_done_func_t)(void*,
     size_t);
 typedef bool (*options_parse_func_t)(void*,
@@ -67,7 +74,7 @@ void options_illegal_opt_arg(
 void options_parse_args(void* opts,
     const struct options_funcs_t* funcs,
     const char* shorts, size_t n_shorts,
-    struct option* longs, size_t n_longs,
+    const struct option* longs, size_t n_longs,
     int argc, char* argv[]);
 
 #define OPTIONS_NAME_(x, t)          \
