@@ -1,4 +1,4 @@
-// Copyright (C) 2016  Stefan Vargyas
+// Copyright (C) 2016, 2017  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -163,7 +163,7 @@ static const struct options_t* options(
         .sib_iter_depth = 0,
     };
 
-    static struct option longs[] = {
+    static const struct option longs[] = {
         { "print-trie",     0, 0, options_print_trie_act },
         { "trie",           0, 0, options_print_trie_act },
         { "print-depths",   0, 0, options_print_depths_act },
@@ -175,7 +175,7 @@ static const struct options_t* options(
     };
     static const char shorts[] = "DRT" "l:p:s:";
 
-    static struct options_funcs_t funcs = {
+    static const struct options_funcs_t funcs = {
         .done  = (options_done_func_t)  options_done,
         .parse = (options_parse_func_t) options_parse,
         .dump  = (options_dump_func_t)  options_dump,
