@@ -102,12 +102,12 @@ static void obj_json_base_init_json(
 
 #define CONF_SET(n, v)                          \
     do {                                        \
-        size_t p =                              \
+        size_t __p =                            \
             INT_AS_SIZE(json_ ## n ## _config); \
-        const size_t* t =                       \
-            ARRAY_NULL_ELEM_REF(types, p);      \
-        ASSERT(t != NULL);                      \
-        if (*t & CONF_BIT(type))                \
+        const size_t* __t =                     \
+            ARRAY_NULL_ELEM_REF(types, __p);    \
+        ASSERT(__t != NULL);                    \
+        if (*__t & CONF_BIT(type))              \
             json_intf_config_set_param(         \
                 this->json,                     \
                 json_ ## n ## _config,          \
